@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
  */
 
-#ifndef CALENDARDELEGATE_H
-#define CALENDARDELEGATE_H
+#pragma once
 
 #include <QStyledItemDelegate>
 
@@ -30,7 +29,6 @@ protected:
 
 private:
     QList<Action> getActions(const QStyleOptionViewItem &option, const QModelIndex &index) const;
-    QHash<Action, QPixmap> mPixmap;
+    QHash<Action, QIcon> mIcon;
 };
 
-#endif
